'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _chai = require('chai');

var _chai2 = _interopRequireDefault(_chai);

var _chaiEnzyme = require('chai-enzyme');

var _chaiEnzyme2 = _interopRequireDefault(_chaiEnzyme);

var _enzyme = require('enzyme');

var _NotificationItem = require('./NotificationItem');

var _NotificationItem2 = _interopRequireDefault(_NotificationItem);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

_chai2['default'].use((0, _chaiEnzyme2['default'])());

describe('NotificationItem', function () {
  var createComponent = function createComponent() {
    var _ref = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

    var _ref$avatar = _ref.avatar;
    var avatar = _ref$avatar === undefined ? 'otherpath.jpg' : _ref$avatar;
    var _ref$nickname = _ref.nickname;
    var nickname = _ref$nickname === undefined ? 'Alice' : _ref$nickname;
    var _ref$id = _ref.id;
    var id = _ref$id === undefined ? 1 : _ref$id;
    var _ref$text = _ref.text;
    var text = _ref$text === undefined ? 'notification text' : _ref$text;
    var _ref$link = _ref.link;
    var link = _ref$link === undefined ? '/somelink.html' : _ref$link;
    var _ref$sentAt = _ref.sentAt;
    var sentAt = _ref$sentAt === undefined ? '2016-08-12T14:35:25+00:00' : _ref$sentAt;

    var author = { avatar: avatar, nickname: nickname };
    var notification = { id: id, text: text, link: link, sentAt: sentAt };
    return _react2['default'].createElement(_NotificationItem2['default'], { author: author, notification: notification });
  };

  it('renders an avatar', function () {
    var wrapper = (0, _enzyme.shallow)(createComponent({ avatar: 'somepath.jpg' }));

    var name = wrapper.find('[data-role="author-avatar"]');
    (0, _chai.expect)(name).to.have.prop('src', 'somepath.jpg');
  });

  it('renders a name', function () {
    var wrapper = (0, _enzyme.shallow)(createComponent({ nickname: 'Bob' }));

    var name = wrapper.find('[data-role="author-nickname"]');
    (0, _chai.expect)(name).to.contain.text('Bob');
  });

  it('renders the text of a notification item', function () {
    var wrapper = (0, _enzyme.shallow)(createComponent({ text: 'notification text stub' }));

    var messageText = wrapper.find('[data-role="notification-item-text"]');
    (0, _chai.expect)(messageText).to.have.text('notification text stub');
  });

  it('renders the sentAt of a notification item', function () {
    var wrapper = (0, _enzyme.shallow)(createComponent({ sentAt: 'some date time stub' }));

    var sentAt = wrapper.find('[data-role="notification-item-datetime"]');
    // eslint-disable-next-line no-unused-expressions
    (0, _chai.expect)(sentAt).to.exist;
  });
});