'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _chai = require('chai');

var _chai2 = _interopRequireDefault(_chai);

var _chaiEnzyme = require('chai-enzyme');

var _chaiEnzyme2 = _interopRequireDefault(_chaiEnzyme);

var _enzyme = require('enzyme');

var _crowdlabTranslations = require('crowdlab-translations');

var _NotificationsList = require('./NotificationsList');

var _NotificationsList2 = _interopRequireDefault(_NotificationsList);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

_chai2['default'].use((0, _chaiEnzyme2['default'])());

describe('NotificationsList', function () {
  var createNotificationsList = function createNotificationsList() {
    var _ref = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

    var translations = _ref.translations;
    var _ref$authors = _ref.authors;
    var authors = _ref$authors === undefined ? [] : _ref$authors;
    var _ref$notifications = _ref.notifications;
    var notifications = _ref$notifications === undefined ? [] : _ref$notifications;
    return (0, _crowdlabTranslations.injectTranslations)(_react2['default'].createElement(_NotificationsList2['default'], {
      notifications: { authors: authors, probes: notifications }
    }), translations);
  };
  context('When there are no notifications', function () {
    it('displays some translated no-message microcopy', function () {
      var translations = {
        'notifications.nonotifications': 'stubbed noinfo'
      };
      var wrapper = (0, _enzyme.mount)(createNotificationsList({ translations: translations }));

      var info = wrapper.find('[data-role="notifications-info"]');
      (0, _chai.expect)(info).to.have.text(translations['notifications.nonotifications']);
    });
  });
  context('When there are some notifications', function () {
    var authors = [{ id: 3, avatar: 'somepath.jpg', nickname: 'Bob' }, { id: 4, avatar: 'somepath.jpg', nickname: 'Max' }];
    var notifications = [{ id: 1, authorId: 3, text: 'banana', sentAt: '2016-08-12T14:35:25+00:00' }, { id: 2, authorId: 4, text: 'apple', sentAt: '2016-08-12T14:35:25+00:00' }];

    it('doesnt show no-notifications microcopy', function () {
      var translations = {
        'notifications.nonotifications': 'stubbed noinfo'
      };
      var wrapper = (0, _enzyme.mount)(createNotificationsList({ translations: translations, authors: authors, notifications: notifications }));

      var info = wrapper.find('[data-role="notifications-info"]');
      (0, _chai.expect)(info).not.to.be.present();
    });

    it('displays a notification component for each notification', function () {
      var wrapper = (0, _enzyme.shallow)(_react2['default'].createElement(_NotificationsList2['default'], { notifications: { authors: authors, probes: notifications } }));

      var notification = wrapper.find('NotificationItem');
      (0, _chai.expect)(notification).to.have.length(notifications.length);
    });
  });
});