'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _chai = require('chai');

var _chai2 = _interopRequireDefault(_chai);

var _chaiEnzyme = require('chai-enzyme');

var _chaiEnzyme2 = _interopRequireDefault(_chaiEnzyme);

var _chaiSpies = require('chai-spies');

var _chaiSpies2 = _interopRequireDefault(_chaiSpies);

var _crowdlabTranslations = require('crowdlab-translations');

var _enzyme = require('enzyme');

var _NotificationsMenu = require('./NotificationsMenu');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

_chai2['default'].use((0, _chaiEnzyme2['default'])());
_chai2['default'].use(_chaiSpies2['default']);

var createComponent = function createComponent() {
  var _ref = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

  var _ref$notifications = _ref.notifications;
  var notifications = _ref$notifications === undefined ? {
    fetchStatus: 'dormant',
    probes: [],
    authors: []
  } : _ref$notifications;
  var _ref$menuIsOpen = _ref.menuIsOpen;
  var menuIsOpen = _ref$menuIsOpen === undefined ? false : _ref$menuIsOpen;
  var _ref$toggleMenu = _ref.toggleMenu;
  var toggleMenu = _ref$toggleMenu === undefined ? function () {} : _ref$toggleMenu;
  var _ref$fetchNotificatio = _ref.fetchNotifications;
  var fetchNotifications = _ref$fetchNotificatio === undefined ? function () {} : _ref$fetchNotificatio;
  return _react2['default'].createElement(_NotificationsMenu.NotificationsMenu, {
    menuIsOpen: menuIsOpen,
    toggleMenu: toggleMenu,
    notifications: notifications,
    fetchNotifications: fetchNotifications
  });
};

describe('NotificationsMenu', function () {
  it('renders a notifications menu', function () {
    var wrapper = (0, _enzyme.shallow)(createComponent());

    var menu = wrapper.find('[data-role="notifications-menu"]');
    (0, _chai.expect)(menu).to.be.present();
  });

  context('when the component mounts', function () {
    it('dispatches the fetchNotifications action', function () {
      var fetchNotificationsSpy = _chai2['default'].spy();
      (0, _enzyme.mount)((0, _crowdlabTranslations.injectTranslations)(createComponent({ fetchNotifications: fetchNotificationsSpy })));

      (0, _chai.expect)(fetchNotificationsSpy).to.have.been.called();
    });
  });

  context('when the dropdown toggle is clicked', function () {
    it('calls the toggleMenu function', function () {
      var toggleSpy = _chai2['default'].spy();
      var wrapper = (0, _enzyme.mount)((0, _crowdlabTranslations.injectTranslations)(createComponent({ toggleMenu: toggleSpy })));
      var dropdownToggle = wrapper.find('[data-role="menu-toggle"]');

      dropdownToggle.simulate('click');

      (0, _chai.expect)(toggleSpy).to.have.been.called();
    });
  });

  context('when the menu is open', function () {
    it('has an active modifier', function () {
      var wrapper = (0, _enzyme.shallow)(createComponent({ menuIsOpen: true }));

      var list = wrapper.find('[data-role="notifications-menu"]');
      (0, _chai.expect)(list).to.be.have.className('notifications-menu--active');
    });
  });

  context('when the menu is closed', function () {
    it('has no modifier', function () {
      var wrapper = (0, _enzyme.shallow)(createComponent({ menuIsOpen: true }));

      var list = wrapper.find('[data-role="notifications-menu"]');
      (0, _chai.expect)(list).to.be.have.className('notifications-menu');
    });
  });
});