'use strict';

var _chai = require('chai');

var _ActionTypes = require('constants/ActionTypes');

var ActionTypes = _interopRequireWildcard(_ActionTypes);

var _menu = require('./menu');

var _menu2 = _interopRequireDefault(_menu);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj['default'] = obj; return newObj; } }

describe('Menu reducer', function () {
  context('when the state is undefined', function () {
    it('returns the initial state of false', function () {
      var result = (0, _menu2['default'])(undefined, { type: 'UNKNOWN_ACTION' });

      (0, _chai.expect)(result).to.eql(false);
    });
  });

  context('when no action matches', function () {
    it('return a copy of the supplied state', function () {
      var state = true;

      var result = (0, _menu2['default'])(state, { type: 'UNKNOWN_ACTION' });

      (0, _chai.expect)(result).to.eql(state);
    });
  });

  context('when action is TOGGLE_MENU', function () {
    it('flips menu bool', function () {
      var stateBefore = true;
      var action = { type: ActionTypes.TOGGLE_MENU };
      var stateAfter = false;

      var result = (0, _menu2['default'])(stateBefore, action);

      (0, _chai.expect)(result).to.eql(stateAfter);
    });
  });

  context('when action is HIDE_MENU', function () {
    it('sets the state to false', function () {
      var stateBefore = true;
      var action = { type: ActionTypes.HIDE_MENU };
      var stateAfter = false;

      var result = (0, _menu2['default'])(stateBefore, action);

      (0, _chai.expect)(result).to.eql(stateAfter);
    });
  });

  context('when action is SHOW_MENU', function () {
    it('sets the state to true', function () {
      var stateBefore = false;
      var action = { type: ActionTypes.SHOW_MENU };
      var stateAfter = true;

      var result = (0, _menu2['default'])(stateBefore, action);

      (0, _chai.expect)(result).to.eql(stateAfter);
    });
  });
});