'use strict';

var _chai = require('chai');

var _ActionTypes = require('constants/ActionTypes');

var ActionTypes = _interopRequireWildcard(_ActionTypes);

var _notifications = require('./notifications');

var _notifications2 = _interopRequireDefault(_notifications);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj['default'] = obj; return newObj; } }

describe('Notifications reducer', function () {
  context('when the state is undefined', function () {
    it('returns the initial state of dormant', function () {
      var result = (0, _notifications2['default'])(undefined, { type: 'UNKNOWN_ACTION' });

      (0, _chai.expect)(result).to.eql({ fetchStatus: 'dormant',
        authors: [],
        probes: []
      });
    });
  });

  context('when no action matches', function () {
    it('return a copy of the supplied state', function () {
      var state = {
        fetchStatus: 'dormant',
        notifications: {
          probes: [],
          authors: []
        }
      };

      var result = (0, _notifications2['default'])(state, { type: 'UNKNOWN_ACTION' });

      (0, _chai.expect)(result).to.eql(state);
    });
  });

  context('when action is FETCH_NOTIFICATIONS_REQUESTED', function () {
    it('sets the send status to fetching ', function () {
      var stateBefore = {
        fetchStatus: 'dormant',
        notifications: {
          probes: [],
          authors: []
        }
      };
      var action = {
        type: ActionTypes.FETCH_NOTIFICATIONS_REQUESTED
      };
      var stateAfter = {
        fetchStatus: 'fetching',
        notifications: {
          probes: [],
          authors: []
        }
      };

      var result = (0, _notifications2['default'])(stateBefore, action);

      (0, _chai.expect)(result).to.have.property('fetchStatus', 'fetching');
      (0, _chai.expect)(result).to.eql(stateAfter);
    });
  });

  context('when action is FETCH_NOTIFICATIONS_FAILURE', function () {
    it('sets the send status to failed and adds an error object', function () {
      var stateBefore = {
        fetchStatus: 'fetching',
        notifications: {
          probes: [],
          authors: []
        }
      };
      var error = {
        message: 'its broken'
      };
      var action = {
        type: ActionTypes.FETCH_NOTIFICATIONS_FAILURE,
        payload: {
          error: error
        }
      };
      var stateAfter = {
        fetchStatus: 'failed',
        notifications: {
          probes: [],
          authors: []
        },
        error: {
          message: 'its broken'
        }
      };

      var result = (0, _notifications2['default'])(stateBefore, action);

      (0, _chai.expect)(result).to.have.property('fetchStatus', 'failed');
      (0, _chai.expect)(result).to.have.property('error', error);
      (0, _chai.expect)(result).to.eql(stateAfter);
    });
  });

  context('when action is FETCH_NOTIFICATIONS_SUCCESS', function () {
    it('sets the send status to success', function () {
      var stateBefore = {
        fetchStatus: 'fetching'
      };
      var action = {
        type: ActionTypes.FETCH_NOTIFICATIONS_SUCCESS,
        payload: {
          probes: [{
            id: 1,
            resolved: false,
            messages: [{
              text: 'We recently asked you about foo',
              sentAt: '2016-07-19T15:02:47.000Z',
              author_id: 2
            }]
          }],
          authors: [{
            id: 2,
            type: 'staff',
            avatar: 'someImage.png',
            name: null,
            nickname: 'Bob'
          }]
        }
      };
      var stateAfter = {
        fetchStatus: 'success',
        probes: [{
          id: 1,
          resolved: false,
          messages: [{
            text: 'We recently asked you about foo',
            sentAt: '2016-07-19T15:02:47.000Z',
            author_id: 2
          }]
        }],
        authors: [{
          id: 2,
          type: 'staff',
          avatar: 'someImage.png',
          name: null,
          nickname: 'Bob'
        }]
      };

      var result = (0, _notifications2['default'])(stateBefore, action);
      (0, _chai.expect)(result).to.have.property('fetchStatus', 'success');
      (0, _chai.expect)(result).to.eql(stateAfter);
    });
  });
});