'use strict';

var _chai = require('chai');

var _effects = require('redux-saga/effects');

var _api = require('api');

var _actions = require('actions');

var actions = _interopRequireWildcard(_actions);

var _listNotifications = require('./listNotifications');

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj['default'] = obj; return newObj; } }

describe('listNotifications', function () {
  context('when the API accepts the request for notifications', function () {
    it('completes the notification request', function () {
      var generator = (0, _listNotifications.listNotifications)();
      var response = {
        data: {
          probes: [],
          authors: []
        }
      };

      var next = void 0;

      next = generator.next();
      (0, _chai.expect)(next.value, 'must trigger FETCH_NOTIFICATIONS_REQUESTED').to.eql((0, _effects.put)(actions.fetchNotificationsRequested()));

      next = generator.next();
      (0, _chai.expect)(next.value, 'must call the API to request notifications').to.eql((0, _effects.call)(_api.api.fetchNotifications));

      next = generator.next(response);
      (0, _chai.expect)(next.value, 'must trigger FETCH_NOTIFICATIONS_SUCCESS').to.eql((0, _effects.put)(actions.fetchNotificationsSuccess(response.data)));
    });
  });

  context('when the API rejects the request for notifications', function () {
    it('fails to provide notifications', function () {
      var generator = (0, _listNotifications.listNotifications)();

      var error = {
        message: 'It has broken'
      };

      var next = generator.next();

      (0, _chai.expect)(next.value, 'must trigger FETCH_NOTIFICATIONS_REQUESTED').to.eql((0, _effects.put)(actions.fetchNotificationsRequested()));

      next = generator.next();
      (0, _chai.expect)(next.value, 'must call the API to request notifications').to.eql((0, _effects.call)(_api.api.fetchNotifications));

      next = generator['throw'](error);
      (0, _chai.expect)(next.value, 'must trigger FETCH_NOTIFICATIONS_FAILURE').to.eql((0, _effects.put)(actions.fetchNotificationsFailure(error)));
    });
  });
});